
Welcome to deprecate's documentation!
=====================================

Contents:

.. toctree::
   :maxdepth: 2

   about
   basics
   api



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
